@@ -2,9 +2,9 @@ from datetime import date
 
 FULL_PAYMENT_DEADLINE = date(year=2021, month=3, day=31)
 CANCELLATION_DEADLINE = date(year=2021, month=4, day=1)
-DEPOSIT = 300
-COST_EVENT_FULL = 1285
-COST_EVENT_BANQUET = 500
-COST_EVENT_CONVENTION = 400
-COST_EVENT_THEME = 450
-COST_EXTRAS_PIN = 55
+COST_FULL = 1150
+COST_DISTRICT_CONVENTION = 280
+COST_BANQUET = 400
+COST_MD_CONVENTION = 320
+COST_THEME = 400
+COST_PINS = 55
